# mammath

Credited modules:
	Sympy
	Tkinter
	Tabulate
	Fractions
	Scipy
	Numpy 
	String
	math
	cmath
	time
	sys
	keyboard
	matplotlib
Functions:
	ShowCalculator - Displays a basic calculator
	HideCalculator - Hides the calculator window
	add - Adds two numbers
	subtract - Subtracts two numbers
	Multiply - Multiplies two numbers
	Divide - Divides two numbers
	Power - Lets you calculate any real power
	recLimit - Sets the recursion limit 
	sqrt - Find the square root of a number
	addFraction - Adds two fractions together
	subtractFraction - Subtracts two fractions 
	multiplyFraction - Multiplies two fractions
	divideFraction - Divides two fractions
	simplifyFraction - Simplifies any given fractions
	root - Calculates any root of a number
	log - Calculates the logarithm of a given number (imaginary numbers are not supported)
	sf - Rounds a number to a given amount of significant figures
	absVal - Returns the absolute value of a given number
	remainder - Returns the remainder of a division calculation
	toDegrees - Converts radians to degrees
	toRadians - Converts degrees to radians
	HCF - Calculates the highest common factor of a given number
	LCM - Calculates the lowest common multiple of a given number
	primeFactors - Calculates the prime factors of a given number
	factorial - Calculates the factorial of a number (n! = n * n-1 * n-2...)
	checkPrime - Returns True is a given number is prime or returns False if otherwise
	primeNumberPrinter - Prints all prime numbers in a specified range
	perfectSquare - Returns True if a given number is a perfect square and False if otherwise
	perfectSquarePrinter - Prints all square numbers in a specified range
	perfectRootCheck - Checks the a given root of a given number to see if it is perfect - returns True if it is, returns False otherwise
	fibonacci - Returns the terms specified in the fibonacci sequence
	fibonacciCheck - Returns True if a given number is in the fibonacci sequence
	fibonacciPrinter - Prints all of the numbers in the fibonacci sequence in a specified range
	divis2Check - Checks whether or not a given number is divisible by two
	divis3Check - Checks whether or not a given number is divisible by three
	divis4Check - Checks whether or not a given number is divisible by four
	divis5Check - Checks whether or not a given number is divisible by five
	divis6Check - Checks whether or not a given number is divisible by six
	divis7Check - Checks whether or not a given number is divisible by seven
	divis8Check - Checks whether or not a given number is divisible by eight
	divis9Check - Checks whether or not a given number is divisible by nine
	divisCheck - Checks whether or not a given number is divisible by another given number
	PercentagetoDecimal - converts a given percentage into decimal form
	PercentagetoFraction - converts a given percentage to fraction form
	FractiontoDecimal - converts a given fraction into decimal form
	DecimaltoFraction - converts a given decimal to fraction form
	DecimaltoPercentage - converts a given decimal into fraction form
	FractiontoPercentage - converts a given fraction to percentage form
	triangleArea - Returns the area of the triangle with the specified values
	trapeziumArea - Returns the area of the trapezium with the specified values
	paraArea - Returns the area of the paralellogram with the specified values
	circleCircumference - Calculates the circumference of the circle with the specified value of the radius
	circleArea - Calculates the area of the circle with the specified value of the radius
	sphereVolume - Calculates the volume of the sphere with the specified value of the radius
	sphereArea - Calculates the area of the sphere with the specified value of the radius
	sphereDiametre - Calculates the diametre of the sphere with the specified value of the radius
	surfaceArea - Calculates the surface area with the specified values of a, b, c (the length, height and width of the shape)
	volume - Calculates the volume with the specified values of a, b, c (the length, height and width of the shape)
	cylinderVolume - Calculates the volume of the cylinder with the specified radius and height of the cylinder
	cylinderArea - Calculates the area of the cylinder with the specified radius and height of the cylinder
	cylinderDiametre - Calculates the diametre of the cylinder with the specified volume and height of the cylinder
	coneArea - Calculates the area of the cone with the specified radius and height of the cone
	coneVolume - Calculates the volume of the cone with the specified radius and height of the cone
	coneRadius - Calculates the radius of the cone with the specified volume and height of the cone
	coneHeight - Calculates the height of the cone with the specified radius and volume of the cone
	sin - Returns the sine of the given angle value 
	cos - Returns the cosine of the given angle value
	tan - Returns the tangent of the given angle value
	sec - Returns the secant of the given angle value
	csc - Returns the cosecant of the given angle value
	cot - Returns the cotangent of the given angle value
	asin - Returns the arc sine of the given angle value (inverse sine)
	acos - Returns the arc cos of the given angle value (inverse cosine)
	atan - Returns the arc tan of the given ngle value (inverse tangent)
	sinh - Returns the hyperbolic sine of the given angle value
	cosh - Returns the hyperbolic cosine of the given angle value
	tanh - Returns the hyperbolic tangent of the given angle value
	asinh - Returns the inverse of the hyperbolic sine of the given angle value
	acosh - Returns the inverse of the hyperbolic cosine of the given angle value
	atanh - Returns the inverse of the hyperboolic tangent of the given angle value
	gamma - Returns the Gamma function at the given value
	lgamma - Returns the natural logarithm of the absolute value of the Gamma function at the given value
	pytheorom - Given a and b, it uses the pythagoras theorom to calculate the hypotenuse
	pytheoromside - Given c and a or b, calculates the missing side with the pythagoras theorom
	cos_rule - Calculates the missings side of any triangle give b, c, and A using the cos rule
	areabytan - Given the number of sides and their side length, calculates the area of a regular polygon with such properties using the tan rule
	pythagroeanTriplets - Prints all pythagorean triplets up to a certain number
	pythagoreanTripletsCheck - Cecks if a given triplet is a pythagorean triplet
	speedCalc - calculates speed based on distance and time
	distCalc - calculates distance/displacement based on speed and time
	timeCalc - calculates the time taken using speed and distance
	quadraticSolver - Calculates all the possible real and complex roots for the given values a, b, c
	sequenceChecker - Checks whether the inputted sequence is linear, geometric or quadratic
	arithmeticSequence - Calculates the nth term of any given arithmetic sequence and returns the specified term number of that sequence
	nthFinder - Finds an Nth term given the nth term formula and term number
	nthRange - Finds a range of numbers from a given sequence
	nthTable - Prints a table of a range of numbers from a given function
	percentageChange - Calculates the percentage change between two given numbers
	percentage - Calculates the percentage of a percentage
	average - Calculates the average of all the inputted values
	consecutiveIntCalc - Returns three positive consecutive integers that add up to the given number
	F - Calculates the force with the mass and acceleration values
	M - Calculates the mass with the force and acceleration values
	A - Calculates the acceleration with the force and mass values
	baseConverter - Converts a base 10 integer to any other base
	IntToBinary - Converts a base 10 integer to binary
	BinaryToInt - Converts base 2 (binary) to a base 10 integer
	IntToHexa - Converts a base 10 integer to a hexadecimal
	HexaToInt - Converts base 16 (hexadecimal) to a base 10 integer
	binaryAdd - Adds two binary values
	binarySubtract - Subtracts two binary values
	binaryMultiply - Multiplies two binary values
	binaryDivide - Divides two binary values
	hexaAdd - Adds two hexadecimal values
	hexaSubtract - Subtracts two hexadecimal values
	hexaMultiply - Multiplies two hexadecimal values
	hexaDivide - Divides two hexadecimal values
	constSearch - Returns the value of the inputted constant
	constTable - Prints the table of all the useful constants
	
Hidden Functions:
	bt - Adds the calculator display to the window
	do_it - Evaluates whatever is on the display
	clear - Clears the display
	PerToFrac - The conversion process from a percentage to a fraction
	